aboutsummaryrefslogtreecommitdiff
path: root/src/nvim/ex_getln.c
diff options
context:
space:
mode:
authorJustin M. Keyes <justinkz@gmail.com>2017-02-18 23:15:27 +0100
committerJustin M. Keyes <justinkz@gmail.com>2017-02-18 23:24:35 +0100
commitbaab49ee89a927f63bfefdb432155a1037afa93a (patch)
tree23da98828033f05ee78d9b406504dabd6fc9f77c /src/nvim/ex_getln.c
parent308ccb6f5e40ba1dbe4abfebc9df3399d7f17504 (diff)
downloadrneovim-baab49ee89a927f63bfefdb432155a1037afa93a.tar.gz
rneovim-baab49ee89a927f63bfefdb432155a1037afa93a.tar.bz2
rneovim-baab49ee89a927f63bfefdb432155a1037afa93a.zip
cmdline: CTRL-R: Omit trailing <CR>.
The "technically correct" interpretation is to execute the first line that is seen (and this is what happens on middle-click paste in Vim). ^M is only intended to "defuse" the newline, so the user can review it. The parent commit changed the behavior to insert <Space> between lines, but that's a higher-risk change: it is arguably possible that some user *wants* the literal ^M chars when e.g. assigning to a register: :let @a='<C-R>b' To avoid that risk, keep the old behavior and only omit the last ^M. This makes `yy:<C-R>0` nicer at no cost.
Diffstat (limited to 'src/nvim/ex_getln.c')
-rw-r--r--src/nvim/ex_getln.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/nvim/ex_getln.c b/src/nvim/ex_getln.c
index 2a4fc067db..d99c8d02f7 100644
--- a/src/nvim/ex_getln.c
+++ b/src/nvim/ex_getln.c
@@ -2471,10 +2471,10 @@ void restore_cmdline_alloc(char_u *p)
///
/// @param regname Register name.
/// @param literally Insert text literally instead of "as typed".
/// @param remspc When true, remove trailing <Space>.
///
/// @returns FAIL for failure, OK otherwise
-static bool cmdline_paste(int regname, bool literally, bool remspc)
+static bool cmdline_paste(int regname, bool literally, bool remcr)
{
long i;
char_u *arg;
@@ -2539,7 +2539,7 @@ static bool cmdline_paste(int regname, bool literally, bool remspc)
return OK;
}
- return cmdline_paste_reg(regname, literally, remspc);
+ return cmdline_paste_reg(regname, literally, remcr);
}
/*
@@ -2471,10 +2471,10 @@ void restore_cmdline_alloc(char_u *p)
/// @param regname Register name.
/// @param literally Insert text literally instead of "as typed".
-/// @param remspc When true, remove trailing <Space>.
+/// @param remcr When true, remove trailing CR.
///
/// @returns FAIL for failure, OK otherwise